<div align="center">
    <img src="https://raw.githubusercontent.com/neptune-ai/neptune-client/assets/readme/Github-cover-022025.png" width="1500" />
 <h1>neptune.ai Legacy</h1>
</div>

<div align="center">
  <a href="https://neptune.ai/">Website</a>
  <span>&nbsp;&nbsp;•&nbsp;&nbsp;</span>
  <a href="https://docs.neptune.ai/">Docs</a>
  <span>&nbsp;&nbsp;•&nbsp;&nbsp;</span>
  <a href="https://neptune.ai/blog">Blog</a>
&nbsp;
  <hr />
</div>

> [!IMPORTANT]
> This is the legacy client.<br/>
> For the new Neptune client, go to **[neptune-client-scale &rarr;][client]**

> [!NOTE]
> If you need to access Neptune Legacy (app version `2.x`), see the [legacy documentation][legacy-setup] for setup instructions.
<hr />

&nbsp;
## Support

If you get stuck or simply want to talk to us about something, here are your options:
* Chat! In the Legacy app, click the blue message icon in the bottom-right corner and send a message. A real person will talk to you ASAP (typically very ASAP).
* Shoot us an email at [support@neptune.ai](mailto:support@neptune.ai).
&nbsp;


[client]: https://github.com/neptune-ai/neptune-client-scale
[legacy-setup]: https://docs-legacy.neptune.ai/setup
